@@ -19,6 +19,8 @@
 
 import logging
 
+import debtcollector.renames
+
 from neutronclient import client
 from neutronclient.neutron import client as neutron_client
 
@@ -47,11 +49,15 @@ class ClientManager(object):
     # in stable versions)
     quantum = neutron
 
+    @debtcollector.renames.renamed_kwarg(
+        'tenant_id', 'project_id', replace=True)
+    @debtcollector.renames.renamed_kwarg(
+        'tenant_name', 'project_name', replace=True)
     def __init__(self, token=None, url=None,
                  auth_url=None,
                  endpoint_type=None,
-                 tenant_name=None,
-                 tenant_id=None,
+                 project_name=None,
+                 project_id=None,
                  username=None,
                  user_id=None,
                  password=None,
@@ -62,6 +68,7 @@ class ClientManager(object):
                  ca_cert=None,
                  log_credentials=False,
                  service_type=None,
+                 service_name=None,
                  timeout=None,
                  retries=0,
                  raise_errors=True,
@@ -72,9 +79,10 @@ class ClientManager(object):
         self._url = url
         self._auth_url = auth_url
         self._service_type = service_type
+        self._service_name = service_name
         self._endpoint_type = endpoint_type
-        self._tenant_name = tenant_name
-        self._tenant_id = tenant_id
+        self._project_name = project_name
+        self._project_id = project_id
         self._username = username
         self._user_id = user_id
         self._password = password
@@ -97,12 +105,13 @@ class ClientManager(object):
             httpclient = client.construct_http_client(
                 username=self._username,
                 user_id=self._user_id,
-                tenant_name=self._tenant_name,
-                tenant_id=self._tenant_id,
+                project_name=self._project_name,
+                project_id=self._project_id,
                 password=self._password,
                 region_name=self._region_name,
                 auth_url=self._auth_url,
                 service_type=self._service_type,
+                service_name=self._service_name,
                 endpoint_type=self._endpoint_type,
                 insecure=self._insecure,
                 ca_cert=self._ca_cert,
